package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$"`0`````````````"`!0````!$``68````#0``+),```````T`"``
M"``H`!P`&P````8````T$```-!```#0```$````!``````4````$`````P``
M`300``$T$``!-`````T````-````!`````$````!`````!`````0``````"K
MG```JYP````%``$```````$``*[`$`&NP!`!KL````)@```2F`````8``0``
M`````@``KM@0`:[8$`&NV````1@```$8````!@````0````$```!1!```400
M``%$````1````$0````$````!&1TY5$`````````````````````````````
M``8````09'3E4@``KL`0`:[`$`&NP````4````%`````!`````$O;&EB+VQD
M+G-O+C$`````````!````!`````!1TY5```````````"````!@```"`````$
M````%`````-'3E4`E551Q)V^#BEW0:L8%19!&1]:A+@````E````10````@`
M```(!!`<`(($0"4`0``XJ`&&H@(``<`I!"A+1S*B.`@,!(H```!%````1@``
M`````````````````$@```!*````2P````````!,````30```$\```!0````
M40```%(`````````5```````````````50```%8```!9``````````````!:
M````7````%T```!?`````````&$```!C``````````````!E````9@```&<`
M````<;+5R2U'WLY)^^"C#N_3ZFNCW:>VF\4OGN/-VX&<^8>6FZ16UD,):QR+
M\CD+ESH-D`6)Q9[B%`S3<`>)#N3_(5<0B@M`G+G$?)I_:F^+`;.;G*E_']_%
M;AQ8<=E\DN.[P.-+K'S49-4*`J?@[=MB,VM*\'IFS*]G[-5%0@'&1^/%CD%]
M+#_EPQW3V_)@;*'Z#O&-N0````````````````````````+\```````````2
M```````#H@``````````$@```````CD``````````!(````````1````````
M```@```````$'@``````````$@```````Y,``````````!(```````$]````
M```````2```````#%P``````````$@```````-,``````````!(```````,#
M```````````2````````KP``````````$@```````3@``````````!(`````
M``*S```````````2```````#4```````````$@```````L0``````````!(`
M``````&A```````````2```````#8```````````$@```````U<`````````
M`!(```````%A```````````2````````X0``````````$@```````>L`````
M`````!(```````&(```````````2```````"@@``````````$@```````C$`
M`````````!(```````+@```````````2```````!V```````````$@``````
M`M$``````````!(```````'D```````````2```````!;P``````````$@``
M`````V<``````````!(````````M```````````@```````"E```````````
M$@```````W0``````````!(```````!X```````````2```````"[@``````
M````$@```````ZD``````````!(```````(J```````````2```````!#P``
M````````$@```````X4``````````!(```````"^```````````2```````!
ME@``````````$@```````O4``````````!(```````++```````````2````
M```"H0``````````$@```````E(``````````!(```````+9```````````2
M````````:@``````````$@```````4(``````````!(```````,>````````
M```2```````!S0``````````$@```````PD``````````!(```````$<````
M```````2```````#FP``````````$@```````N<``````````!(```````&O
M```````````2````````/```````````(````````/,``````````!(`````
M``%_```````````2```````#>P``````````$@```````(<``````````!(`
M``````!0```````````@```````"F0``````````$@```````S\`````````
M`!(```````(^```````````2```````#+```````````$@```````F,`````
M`````!(```````*J```````````2```````#-P``````````$@```````4X0
M`&A@`````!(```````1,$`!3,```"WP2```,```$EA``3D````)4$@``#```
M`_40`&LP`````!(```T```.]$`&Q(`````0A```9```#^Q``2:`````,$@``
M#```!'P0`&30````P!(```P```">$`!I(``````2```````!+1`!L2@````$
M$0``&0``!%D0`;$0`````!```!<```-)$`&Q)`````01```9```$6Q`!L1``
M````(```%P```[P0`;$@````!"$``!D```/K$`!ED`````02```,```$C!`!
ML1P````$$0``&```!*L0`$FP```"8!(```P```$"$`&Q+`````$1```9```#
MNQ`!L2`````$$0``&0```[80`!/@```"@!(```P```3*$`!0H````+`2```,
M```$#!``45`````X$@``#```!"<0`&-0````V!(```P```/:$`&Q(``````0
M```9```#YA`!P5@`````$```&0```G,0`&MP````!!$```X```3T$`!>L```
M!)P2```,```$9A``2-````#,$@``#```!%\0`!9@````)!(```P```&]$`!F
M(``````2```````$0!``3'````'0$@``#````],0`;$@`````!```!@```0S
M$`!,$````%02```,```$V!``9#````!,$@``#```!*,0`$@P````0!(```P`
M``'V$`&Q,````!,1```9```$N!``49````&<$@``#```!*40`!.<`````!(`
M``L`;&EB<&5R;"YS;RXU+C(P`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])5$U?<F5G
M:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET
M,P!097)L7W-A=F5?9&5S=')U8W1O<E]X`%!E<FQ?871F;W)K7VQO8VL`<&5R
M;%]C;VYS=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF
M=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U
M;7``4&5R;%]N97=35G!V`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P
M97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?
M<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I
M;F0`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O
M=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E
M<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``;&EB9&PN<V\N,@!L:6)M+G-O+C8`
M;&EB<'1H<F5A9"YS;RXP`&]P96XV-`!L<V5E:S8T`')E860`<'1H<F5A9%]G
M971S<&5C:69I8P!?7V5R<FYO7VQO8V%T:6]N`&-L;W-E`&QI8F,N<V\N-@!?
M24]?<W1D:6Y?=7-E9`!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``
M7U]S=')D=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD
M:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`;65M<V5T
M`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?
M8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I
M9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER
M-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C
M7W-T87)T7VUA:6X`7U]E;G9I<F]N`&QI8F-R>7!T+G-O+C$`7V5D871A`%]?
M8G-S7W-T87)T`%]E;F0`7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X
M96,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``<&%R
M7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A=&%?<W1A
M<G0`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P
M87)?<&P`<&%R7VEN:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S
M971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]#
M3$5!4E-404-+`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C(`1TQ)
M0D-?,BXP`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR`$=,24)#7S(N-``````"
M``(``P````(``@`"``(````"```````$``(``@````(``@````````````4`
M!@`"`````@`"````!P````(``@````(``@`&````!````````@`"``(``P`"
M```````'````!`````(``@````````````@```````(`"``#``@``P`"``(`
M```!``$``0`"``$``0```````0`"``$``@`!``$``0````(``0`!``$``0`!
M``$``0`!``$``0````$``0`!``$``0````$``0`!``(```(:````$````#`-
M:6D2````!@``!0H````0#6EI$`````,```44```````!``4```)I````$```
M```-:6D2````"```!0H````0"6D9=`````<```4>````$`EI&7(````%```%
M*@```!`-:6D4````!```!38````0#6EI$`````(```44`````!`!K_```!\4
M`````!`!L2```%83`````!`!L20``$\3`````!`!L2@``$T3`````!`!L2P`
M`%43`````!`!L3```&<3`````!`!L`````$5`````!`!L`0```(5`````!`!
ML`@```,5`````!`!L`P```45`````!`!L!````85`````!`!L!0```<5````
M`!`!L!@```@5`````!`!L!P```D5`````!`!L"```&$5`````!`!L"0```H5
M`````!`!L"@```L5`````!`!L"P```P5`````!`!L#````T5`````!`!L#0`
M``X5`````!`!L#@```\5`````!`!L#P``!`5`````!`!L$```!$5`````!`!
ML$0``!(5`````!`!L$@``!,5`````!`!L$P``!05`````!`!L%```!45````
M`!`!L%0``!85`````!`!L%@``!<5`````!`!L%P``!@5`````!`!L&```!D5
M`````!`!L&0``!H5`````!`!L&@``!L5`````!`!L&P``!P5`````!`!L'``
M`!T5`````!`!L'0``!X5`````!`!L'@``!\5`````!`!L'P``"`5`````!`!
ML(```"$5`````!`!L(0``"(5`````!`!L(@``",5`````!`!L(P``"05````
M`!`!L)```"45`````!`!L)0``"85`````!`!L)@``"<5`````!`!L)P``"@5
M`````!`!L*```"D5`````!`!L*0``"H5`````!`!L*@``"L5`````!`!L*P`
M`"P5`````!`!L+```$45`````!`!L+0``"T5`````!`!L+@``"X5`````!`!
ML+P``"\5`````!`!L,```#`5`````!`!L,0``#$5`````!`!L,@``#(5````
M`!`!L,P``#,5`````!`!L-```#05`````!`!L-0``#45`````!`!L-@``#85
M`````!`!L-P``#<5`````!`!L.```$P5`````!`!L.0``#D5`````!`!L.@`
M`#H5`````!`!L.P``#L5`````!`!L/```#P5`````!`!L/0``#X5`````!`!
ML/@``#\5`````!`!L/P``$`5`````!`!L0```$$5`````!`!L00``$(5````
M`!`!L0@``$,5`````!`!L0P``$05`````)0A__!\"`*FD`$`%)/!``A"GP`%
M?\@"IC_>``([WIQ$@![__"^```!!O@`(2`!3N8`!`!1\"`.F@\$`"#@A`!!.
M@``@E"'_P'P(`J:3P0`XD`$`1)/A`#R080`<D($`&)"A`!0X80`<.($`&#BA
M`!0_X!`"@2*/^)$A`"PY(```2`!3E3R`$``XA&A@/&`0`'R%(W@X8VD@2`!0
M33T@$`*+R;$L+YX``$">`"Q(`%*9/4`0`B^#``"0:L%409X"`#_@$`)(`%'A
M@'^Q*$@`52F;PP<%@'^Q*$@`51V)(P2V?&H;>(!_L2AA*0`"F2H$MD@`506!
M(0`<B4,$MCDI``5A2@`!F4,$MCU`0S"100`(D2$`##U`$`#`"FOP/4`0`,EA
M``C]BP`HR`IK^#U`$`#\#``JR8IL`/^`8`!!G0$\52,0.C_@$`)(`%)-@4$`
M&("A`!P]`!`"._^Q1($(L1R!*@``+X4``7QK&WB0?Q`(D0,`")$C```](!``
M.2EO')$C``0](!``.2EO()$C``PY(``$D3\0!$"=`"A4J1`Z.0,`##DI__A5
M*?"^.2D``7TI`Z:%*@`$E2@`!$(`__A4J1`Z@'\0$#R`$``Y*0`,.4```#B$
M2'`XI0`#?69;>#C@``!]2TDN2`!3/7Q^&WE!@@!D@'\0$$@`4/T\8!``.($`
M*#AC;,Q,QC&"2``I&2^#``!!G@!0@'\0$$@`4)E(`%+5?\/S>($A`"R!0H_X
M?2E2>3E```!`@@"`@`$`1(/!`#B#X0`\."$`0'P(`Z9.@``@@'\0$$@`4TU\
M?AMX2___E(!_$`PO@P``09X`)$@`345+__^D/&`0`#R`$`(X8VWX.(2Q,$S&
M,8)(`%'I/&`0`#B!`"@X8VQH3,8Q@D@`*(4O@P``D'\0#$&>_VQ(`$T%2___
M9$@`4`TX8``!2`!1-7PI"WA4(0`V.````)0A__!\"`.FD`$``#T`$`"%J&M@
M2`!14````````````````#T@$`(\8!`".2FQ'#ACL1PY*0`#?2-(4"N)``9,
MG0`@/2```#DI```OB0``39X`('TI`Z9.@`0@8````&`````\8!`"/(`0`CAC
ML1PXA+$<?(,@4'R$%G!\A`YP?(0!E4V"`"`]0```.4H``"^*``!-G@`@?4D#
MIDZ`!"!@````E"'_\'P(`J:3X0`,/^`0`HD_L4.0`0`4+XD``$">`!!+__]A
M.2```9D_L4.``0`4@^$`##@A`!!\"`.F3H``(#T@$`(Y*:[(?2-+>($C```O
MB0``0)X`#$O__VA@````/2```#DI```OB0``09[_[)0A__!\"`*F?2D#II`!
M`!1.@`0A@`$`%#@A`!!\"`.F2___,```````````````````````````````
M``````"4(?M0?&P;>'P(`J8Y0P`P.&``"'QI`Z8Y````D`$$M)'!!&B1X01L
MD@$$<)(A!'22001XDF$$?)*!!("2H02$DL$$B)+A!(R3`020DR$$E)-!!)B3
M802<DX$$H).A!*23P02HD^$$K#DA`=B``H_XD`$$7#@```!@````8````(3*
M``B1"0``@.H`!)#)``0Y*0`0D0G_^)#I__Q"`/_D.*``0#B!`CA\J0.F.&``
M`#B$``B`Y/_8@00`!($D_]R!1```@*3_J(#$_ZQ\ZE)X?2E">(#D_YR!!/^8
M?4HJ>'TI,GA]2D)X?2DZ>%5*"#Q5*0@^?2E3>)!D`!B1)``<0@#_L(%,`""!
M;``D/2!:@CM```"`P0'8@.$!W&$I>9D[P```@<P`&('L`!Q\YU@4?,91%("!
M`>"`H0'D@BP`'(),`!1]9TH4?*5X%'R$<12![``,@@P`"'T'6!!]"$$0@FP`
M$(*,``!\Y4H4@L$!Z(+A`>Q\RC-X?0@`T'XC>'A]2%(4?*4X$'RE*1!^2'@X
M?=R`>(',``!\>4-X?(8C>(!L``2`C```?*4`T'Y]@#A^=:!X?,4R%%23\`)5
MQ2@T5&0H/G^8ZWB#K``4@XP`$'R;*WA5X/`"?*O8%'R*T116"_`"5>KPOH'L
M``1^]^@4?M;A%'UJ4WA]7P-X5&CPOG_*<#A\I<@4?(3!%']W2A1]7*MX?[08
M>'_J>#B`80'T?FA#>%7@\`)]"P-X?5VC>(*!`?`Y0```?!?8$'P``1!\B%`X
M?.?H%'S&X11^HTH4?_<H>'RD6#A4LR@^?1CS>#I```"!`0'\?```T'[:LWA\
MYY@4?,:1%']`TA1^^2-X?&.H$'QC&1!4MO`"?SG8%'\8T12#00'X?VA*%%2E
M\+X[@```?+VS>%3W*#Y\8P#0.L```'T(V!!]"$$0?SFX%'\8L11]8#AX?H.B
M%'S#X#A\YN@X?_^H%'_>H11\9%-X@&$"!'P%,WA]"`#0.,```'](TA14]_"^
M?P@P.%3@\`)]:]@4?4K1%'[G`WA]%.-X?O\H%'[>(117*/"^@($"`'RC2A17
M.O`"?[O(>'\@.#A\8R@0?&,9$%<_*#X[P```?1G3>($!`@Q__[@4?]ZQ%']U
M`WB"P0((?NA*%#L```!^M5@4?I11%'QC`-!\@R(45_LH/G_#P#@[0```?0BX
M$'T(01!^M=@4?I31%'QJ,WA_O2@4?YPA%(!A`A1\Y/AX?^7(.'T(`-!\BRMX
M.(```%?^\+Y7X/`"?[U8%'^<411^R+(4@4$"$'UC2A1^B"`X?\4#>'T:PWA6
MOR@^?.>X%'S&L116J/"^5K;P`CO```!\8U@0?&,9$'^]^!1_G/$4?S>H>'T?
MLWA^H"@X@0$"''[[`WA\8P#0?.?8%'S&T10[P```?VA*%'U#4A1]"-@0?0A!
M$'^#\#A_.5@4?QA1%%>U*#Y\J^AX?ZKX.#J```!^M3@4?I0Q%'QV(WB`80(D
M@T$"&'UW4WA_.;@4?QBQ%#E```!]"`#05Z;POE>G\`)_2-(45KTH/GZ(4#@[
M@```?SGH%'\8X11\RSMX@,$"('SC2A1]%O-X5KSP`E:H\+Y\I=@4?(31%'_]
MJ'A^H%@X?&,X$'QC&1!]%>-X@0$"+(.!`BA_MP-X?&,`T'^H2A1^]R@4?M8A
M%#J```!\PS(45SLH/CM```!]".@0?0A!$'[WV!1^UM$4?P.@.'__.!1_WC$4
M?6;(>'\GJ#A\9%-X?,4[>(!A`C0XP```?0@`T%<[\+Y7(/`"?_\H%'_>(11_
MB.(4@($",'[(,#A_9P-X?1BC>'RC2A16^R@^?6OH%'U*X116Z/"^5OSP`CM`
M``!^O;AX?__8%'_>T11^X#@X?1OC>($!`CQ\8R@0?&,9$'^Y`WA]:\@4?4K!
M%(,!`CA_*$H4?&,`T#M```!\@R(4?0C($'T(01!7_2@^.X```'_#T#A_O5@4
M?YQ1%'S^^'A_X-@X?*6H%'R$H11\=C-X@&$"1'_7`WA7Z_"^.\```%?J\`)]
M"`#0?7]3>'REN!1\A+$4@4$"0'\(PA1_B/`X?Z#X.']\Z'A]%--X5[<H/E>H
M\+XZP```5[WP`GREN!1\A+$4?6-*%'T7ZWB!`0),?.?(%'S&P11\8U@0?&,9
M$(,!`DA_E0-X?RA*%'SGJ!1\QJ$4?&,`T'T(R!!]"$$0.L```%2U*#XZ@```
M?4-2%'SGJ!1\QJ$4?(.P.'_@*'A\I+@X?6O8%'U*T11]"`#0?'SS>(!A`E1\
M'2-X.H```'\(PA14I/"^?CGX%'X8\11\R*`X@,$"7(,!`F!]:^@4?4KA%(.!
M`E!4I?`"?)4K>%3E*#XX@```.T```'UK*!1]2B$4DB$`1((A`F1\IDH4@($"
M6'^C2A1\QB@0?,8Q$)-!`!!_,4H4?&/H$'QC&1!\Q@#0?C'($'XQB1!\AB(4
M@,$";'QC`-`YX```?F6H%'Y$H11_@^(4567P`E5D\+Y4[O"^?C$`T#O```"1
MX0!85._P`G\1PA1]SWMX?)$K>("!`FA\IDH4D\$`&#M@``!__;@4?]RQ%#N`
M``!\9B@0?&,9$)(!`$"`P0)TDD$`L))A`+2300!@DV$`().!`&B1X0`4@Z$`
M$'Z@6'A5<R@^?&,`T('!`H!]2N@X.@```'U<HWA]:G@X@H$">'P=4WA\@R(4
M@&$`0'U]^!1]7/$4@X$`$(.A`!0Z0```?WGH%']8X12180#,?69*%($A`GR3
M00"X?1JS>#T`;ME_Q8@4?Z2!%("!`$1A".NA?.6H.'ZI0A1\QE@0?,8Q$'TI
MJ!!]*4D0D4$`R(%!`G!\Q@#0?2D`T'[G.'A]1E(4?HFB%(#!`H2!(0*,DV$`
MO)/!`%1\^RMX.\```(#A`I1]YD(4D\$`<'_DV!1_P]$4?VE"%(-!`HA\QG@0
M?,8Q$'TIV!!]*4D0?_^8%'_>D12"00`8?,8`T'TI`-!]QG(4?TG2%%?F\`)7
MZ?"^.(```'TF,W@[@```@2$"G)#!`!R0@0!`.L```#A@```X@```DZ$`4).!
M`'B2P0"`DX$`B)!A`)B0@0"0@L$"D#B```""80`<?N="%#A@``!\Y[@0?.<Y
M$#L```!\RY@4?*J1%'_JB#B0H0#`D,$`Q).!`*"`H0`0?\:`.(%A`!2#@0"P
M?.<`T'YI0A1\QBMX@Z$`M)"!`-"0P0`H?6;X>(/!`,A\RE-X?L>R%(#!`%B`
M`0`8D4$`+'TIF!!]*4D0@D$"F)!A`*A]*0#0?DF2%(%!`"B!80`L?+U8%'R<
M4117ZR@^@^$`S)%A`%Q@0@``@.$`7'^_.!1_GC$4.\```(#A`J23P0!8@\$`
M(%>F\+Y7JO`"?,I3>'^)`#B100`D?2F#>((!`+B1(0`P?BGH>((A`+P[@```
M@^$`)'UU^!1]5/$4@J$`'#J```"2@0"P@H$`,)%!`,@Y0```D4$`$'^JJ#A]
M*E-XD6$`S)%!`#1_YT(4?.?X$'SG.1!\YP#0@J$`-(#!`JR#P0*@@`$`('UQ
MJ!1]4*$45[$H/H*!`&"2(0!D@B$`5'_'\A0Z````D@$`N#H```"2`0!@@@$`
M4'^F0A1\QN@0?,8Q$).!`"B#@0*H@J$`9'S&`-!_AN(4?*6H%'R$H114H_`"
M5*GPOGTI&WA\AP`X@($`:'TY2WA^K\@4?H[!%('!`!B!X0`<DJ$`-(*A`"1\
MYW-XD.$`.'WG*'A\HZ@XDH$`,'SC&WB080`\@&$"M('!`#A@0@``@>$`/'ZQ
M>!1^D'$45+`H/I(!`&PYX```.<```)'A`%"1P0#8@<$`F'XC0A1\8X@0?&,9
M$("A`&Q\8P#0?6LH%'U*(10X@```D($`:%5E\+Y59_`"?*<[>'U8P#B0X0"<
M?.E*>&!"``"!X0"<?-MX%'RZ<10[0```D*$`&)#!`!R``0*\@($`)'UFR#B#
M80`@@<$`P'R*6'B!X0#$@@$"L'\8VWA]1C-XDP$`2)#!`$Q^`X(4@,$"Q)-!
M`)B#00*X?V!"%'P`V!!\``$0?```T(,!`$B#(0!,?T#2%'ROR!1\CL$456\H
M/H,!`'"1X0!T.R```#G```"3(0#`D<$`2#G```"1P0!PD<$`X('!`*B#(0!T
M?77(%'U4P10Z@```DH$`Z%5C\+Y5:O`"?&I3>'TI6GB100"LD2$`1'U'.GA_
M)D(4?,;($'S&,1!\Q@#0@>$`K'ZW>!1^EG$4@L$`R('!`$"!X0!$@N$`S)*!
M`4B2H0%,?K=X%'Z6<115;R@^@L$`>)'A`'PYP```8$(``(+A`'R1P0!X@2$"
MS(,!`L!\I;@4?(2Q%#K```!^Z4(45*/POE2D\`)\9"-X?.<J>(!A`M20@0`4
MD.$`C'R`4G@Y0```D4$`0(%!`!!]*;@0?2E)$)+!`*B"P0+(?2D`T'\&PA1^
MR;(4@2$`*#C```"!80`4D,$`R'SC0A1\8S@0?&,9$'WS6!1]TE$4@4$`B()!
M`#""80`T@6$`C'QC`-"1P0%0D>$!5'WS6!1]TE$45*LH/H)!`("180"$.*``
M`#E```"0H0"`D4$`B()A`(1^M9@4?I21%#J```!6J_"^5J7P`GUE*WA\`*IX
M@6$`')"A`"Q\I")XD($!8)`!`*2!00`L?G]0%'Y>212!00`8DD$!6))A`5R#
MP0"@@^$`I($A`)"`@0+L?FOX%'Y*\116OR@^@`$"W(#!`M"3X0"4@^$"Y#O`
M``"2@0#P?_]"%)/!`*"3X0`4@^$"]'Z@0A23P0$(.\```)/!`1"3P0$8@4$`
ME'P`J!!\``$0?,,R%'WO4!1]SDD4.4```)%!`)!]1$(4.2```)%!`!Q]7T(4
MD4$`)(%!`OQ\``#0D2$`^)$A`0!]2D(4D2$!(#D@``"100`L@4$#!)$A`2B1
M(0$X.2```'U*0A21(0$PD2$!:)$A`4`Y(```D2$!<)$A`7B1(0&(.2```)%!
M`#2#P0+\5>OP`I$A`8"1(0&0@2$`+(*!`MB`80,$@<$##'U>2!!]2E$0@\$"
M^($A`!Q^@*(4D\$`*'R$2!!\A"$0@\$"Z'U*`-!\A`#0?(3R%(/!`"20@0`8
M@($`-(`!`"A](R`0?2E)$(!A`!1]2@(4@`$"Y'TI`-"100`H@4$#`'R`&!!\
MA"$05>/POI%!`#!]7_`0?4I1$(/A`O!\8UMX@\$"X)!A`-R3X0`@?(0`T'QE
M*GA\A/(4D*$!L)"!`!!\KD(4.(```'U*`-"0@0&@@($`V)"A`#R``0`@?4H"
M%'P.*!!\``$0@*$`W)%!`"!__2@4?]PA%#E```"100&8D\$!J("A`6!\``#0
M@\$`6(.!`4A\I7IX@Z$!3)/A`:R0H0!<@<$`T&!"``"#X0!<?7WX%'U<\115
M_R@^D^$`U#N````[H```.\```).!`%B#@0%0DZ$`V)/!`-"#H0%4@\$`N('A
M`-1\LW@4?))Q%('A`#"`@0,4@D$#"('!`Q!]*7H4?>1"%'T$>!!]"$$0D2$`
M,%2D\+Y4J?`"?`"2%()!`,!\B4MX@($`L)`!`#B1(0#$?2,:>'T(`-!]R'(4
M.0```()A`,1^,9@4?A"1%()A`;!^<RIXDF$`O&!"``"#X0"\?GWX%'Y<\114
MOR@^D^$`M#N````[H```.\```).!`+"3H0#`@*$`M)/!`+B#P0#H?6LH%'U*
M(12`@0%<56KP`E5E\+Y\I5-X?&-:>(%!`QB0H0#LD&$`5(!A`5A\H$IX/2"/
M&V$IO-R#X0#L?[OX%'^:\12#00!0@V$`5'_DV!1_P]$457LH/H%A`QR380!D
MDX$!L).A`;2#@0!@.&```']I6!1_2%$4D&$`8)-A`50X@```.V```)-!`5"#
M00&H@Z$`9)-A`%"#80&L?G/H%'Y2X12#@0"HD($`J("!`)A6:O`"5F/POGQC
M4WA\`)IXD&$`K)`!`)Q\92IX.4```)"A`4B100#H@4$`:(.A`*R`H0"<?SGH
M%'\8X11_NR@4?YHA%%9E*#X[0```D*$`;&!"``"!80!L?_]8%'_>412!00,@
M@6$#)#O```"300!H@T$`R'YI6!1^2%$45^3POE?J\`)\A%-XDD$!6)"!`,Q\
M@QIXDF$!7#I```!@0@``@V$`S'UWV!1]5M$4@L$#*(+A`RQ_:;@4?TBQ%)%!
M`<""P0!(.4```)-A`62#80%(D6$!Q)%!`)A_>_IX@4$`<)-!`6"380!T.T``
M`)-!`'"3P0!(DT$!2(%A`'1^,5@4?A!1%%?K*#Z180!,@6$#-#E```"100#(
M@4$#,(+A`$Q_O;@4?YRQ%'[I6!1^R%$45Z7P`E>J\+Y]2BMX?&/J>)%!`/1]
M0")X@($`\)+!`:B2X0&L@*$`])!A`'PX8```@L$`>(+A`'Q_YR@4?\8A%("A
M`;"`P0&T.(```(.!`."080!X?V:X%']%L117MR@^@&$`@(%A`SR2X0#DD($`
MX(.A`.1^,>@4?A#A%(.!`0@Z````?`"*>%8F\+Z0`0"$5B?P`GS'.WA\YE)X
M@4$#.)#A`0Q^Z5@4?LA1%(%!`$"`@0"$DL$!L#K```"2X0&TDL$`0'\Y(!1_
M&!D45B0H/H.A`0R"P0`0D($`1(+A`!1^M>@4?I3A%#N```"3@0"`@6$`1'][
M6!1_6E$4@4$#0(%A`T0[0```?(E8%'QH41179?`"5VKPOGU**WA\QMIXD4$!
M))"!`;PX@```D&$!N(!A`2"0@0#P?4<Z>("!`220P0"4@*$!P(#!`<1_MR`4
M?Y89%(!A`)"!80-,DT$`$("!`)1^YB`4?L49%%=D*#Z`H0"(D($`C#A@``"0
M80"(@,$`C'\Y,!1_&"D4.P```%<F\`)7)?"^?*4S>'SGRGB0H0$\?*!2>(%!
M`TB0X0#\?VE8%'](412!00`8@6$`')-!`<"380'$@T$!.(-A`3Q\B]@4?&K1
M%(%!`*`[0```DT$`&)!A``B0@0`,@&$`^("!`/Q\_R`4?-X9%%<D*#Z0@0"D
M.\```)/!`)!@0@``@6$`I'[W6!1^UE$4@4$#4(%A`U16X_`"?VE8%'](4116
MZO"^?4H;>)-!`<B380',D4$!1'P`NGB#00`@@V$`)'U%*GB0`0$4D\$`H(/!
M`4""P0$`@6$#7(/A`41\F_@4?'KQ%#O```"#X0`LD\$`^(/!`"B080$@D($!
M)(!A`1"`@0$4.T```)-!`"!^M2`4?I09%%;D*#Z0@0$$8$(``(+A`01\Y[@4
M?,:Q%'RE.GA4Y/"^D*$!+%3F\`)\AC-X?,-2>(%!`UB0P0&,?NE8%'[(412!
M00&(DL$!0)+A`42"P0$H@N$!+(%A`8Q\O;@4?)RQ%%3W*#Z2X0$<?W]8%']>
M410[@```.L```)-!`3B380$\@T$!&(-A`1Q^M=@4?I31%#M@``"380`H@4$#
M8(%A`V16I_`"?&.J>(*!`3"080%LDX$!`'_)6!1_J%$45JKPOH.!`#"!80-L
M?4H[>)%!`:23P0$L.\```).A`2B#H0`TD\$!"(/!`:!]1C)X@^$!I']]^!1_
M7/$4@X$!:(.A`6R300$8DV$!'(-!``B#80`,?_OH%'_:X116O2@^DZ$!-#M`
M```[8```DT$`,)-A`1"#00#8@J$!-'REJ!1\A*$4@H$`.(*A`#Q4I/"^5*?P
M`GR'.WA\QBIXD.$`W'SD4GB!00-H?ZE8%'^(4123@0$PDZ$!-(-A`-Q]==@4
M?531%)%!`6B180%LD,$!?(.!`2"#H0$D@4$!>(*!`7"`80$X@6$!?']]6!1_
M7%$45*LH/H%!`8"180%T8$(``(*A`71__Z@4?]ZA%#J```!7_"@^?(3Z>).!
M`820@0&4@($!/%?F\`*!80&$?WM8%']:412!00&0@6$!E%=E\`)_I%@4?X-1
M%(%!`5"!80%45V3POGR%*WB3@0#8D*$`5#N```"3H0#<DX$`.(.!`%"#H0!4
M?(OH%'QJX117?2@^@X$!F).A`9R080!0D($`5(!A`-B`@0#<@Z$!G'UDZ!1]
M0^$45^KPOH!A`1A]1C-X?,<Z>%5J\+Y\Y]IXD.$`7("!`1Q\IS)X@T$`6(-A
M`%Q\YUIX@X$`T)#A`+1_Y-@4?\/1%%5[*#Z`80%H@($!;)-A`-2#00"PD,$`
MQ%5F\`)]2C-X@,$!6'U%*GA]4U-X@V$`M(.A`-1__^@4?][A%'^DV!1_@]$4
M@&$`P("!`,2#00%@@V$!9'RE^GA7Y_`"@\$`<)"A`&1][R`4?<X9%("!`&!7
MX_"^?&,[>(#A`5R080!T?&M3>'QJ4#B`H0!D?>\H%'W.(11\IY@4?(:1%()!
M`+A7YR@^@^$`=)#A`+Q\^_@4?-KQ%(-!`*B#P0!08$(``()A`+Q_O9@4?YR1
M%%>R*#Y7O_"^DD$`K%>@\`)_X`-X?ZM8.'P?&WA]:E-XD4$`[)/A`%A\`Q@X
M@V$`K(/A`%20`0%,@4$`Z(%A`.Q][]@4?<[1%()!`:B"80&L@<$`R'^_6!1_
MGE$4@\$!2%7J\`*#X0%,?W/X%']2\115_R@^@D$`:(/!`)B3X0!L8$(``()A
M`&Q_O9@4?YR1%()A`%B"00&P??^8.()A`;1_XQMXD&$`G%7C\+Y\:E-X?4,#
M>'U``#A_HQ@X?5%3>'Q@`WA7H_`"D`$`S(/A`)Q\I?@4?(3Q%'_SB!1_TH$4
M@B$`>%>S*#Z280!,@>$`S()A`;Q\YW@4?,9Q%('!`$B!X0!,?*5X%'R$<117
MI/"^@>$`X('!`/!\@QMX?&13>'QJ4#A\I"`XD&$`]'R*4WB100#D5*KPOF!"
M``""`0#D?WN`%']:>114L"@^D@$`?&!"``""00!\?.>0%'S&B114IO`"@D$!
MN('A`/1]2C-X@B$!Q'U&&WA]0Q@X?.8P.'^S>!1_DG$4@>$`@()!`$!\PQMX
M@<$!R)!A`(1]65-X5.;P`E3C\+Y\8S-X@,$`$)!A`*2"`0"$?_^`%'_>>12"
M`0'`@>$!S'RQR!1\D,$45/$H/H,!`(B"`0"@DB$`1((A`*1\9U-X?&I0.()A
M`$1_>Y@4?UJ1%()A`42#00#X?V<X.%=K\`)\ZE-XD4$`C%=J\+Y]2EMX?4L;
M>'U#&#A]5U-X@R$`C'^]R!1_G,$45WDH/I,A`!1@0@``@.$`%'__.!1_WC$4
M?.^(%'S.@12"(0"0@\$`('_K6#A]8QMX5^OPOI!A`)17X_`"?6,;>'QK4WA\
M:E`X@D$`E'RED!1\A(D4@D$!0'\SN!1_$K$45_,H/H+!`!B280`<8$(``(+A
M`!Q_O;@4?YRQ%'^K6#A]:E-XD4$`_%>J\+Y@0@``@V$`_'SGV!1\QM$45[LH
M/I-A`"1@0@``@^$`))!A`0R!P0$H@>$!+'RE^!1\A/$45Z3P`H(!`0B"80$T
M?4HC>(-!`#!]1!MX?4,8.'RD(#A]55-X?(,;>((A`0Q4I/`"D&$!!'_OB!1_
MSH$4@B$!`('!`#@Z````@D$!!'\YD!1_&(D4@D$!,'^SJ!1_DJ$45+,H/H*!
M`"B280`L5*7POCI```!\I2-X8$(``(*A`"Q\YZ@4?,:A%'RF4WB"H0$0?*I0
M.'SF,#A4X_"^?,I3>#C```"100$45.KP`GQC4W@Z@```?&HK>'QK*#B"P0$4
M?_^P%'_>J114]B@^DL$`-#K```!@0@``@V$`-'\YV!1_&-$4?+LK>#M```!7
M(/"^5R3P`GP$(WA7("@^D`$`/'\J4#A]1UMX@4$#<(%A`W1\@!MX?.?H%'S&
MX10[@```?6M(%'U*011]:]@4?4K1%#M```"!X0`\?_]X%'_><11\GA@X?^``
M.%?]*#Y\&_-X5_GPOH/!`WA7Y?`"@^$#?'SGZ!1\QN$4?R4K>'RF(WA__T@4
M?]Y!%'R@(#A]:]@4?4K1%'Q]&WA4^R@^?.8P.#N```!4X_"^5.?P`GQC.WA_
M_^@4?][A%(#A`X1\W0-X@,$#@#M````[@```?6O8%'U*T11\YT@4?,9!%'QJ
M*WA__^@4?][A%'Q@*#A\FR-X?6I0.#M```!5>?"^?.?8%'S&T115?2@^?5L#
M>(%!`XA59/`".X```(%A`XQ_O?@4?YSQ%#M```!_)"-X?.?8%'S&T11]:T@4
M?4I!%'R_*WA\@!MX5[LH/CO````[0```?6OX%'U*\11\Y]@4?,;1%(-!`Y"#
M80.4?)P8.'^@`#A7N?"^5Z7P`GP?XWA_)2MX.\```'][2!1_6D$4?_]8%'_>
M411\IB-X?'<;>%3]*#Y\HR`X?.8P.#N```!__^@4?][A%'\[N!1_&K$45.OP
MOGS;&WB`P0.85.KP`H#A`YP[0```?6I3>'][R!1_6L$4?NDX%'[(,11]2RMX
M5_[POE?C\`)_PQMX?^M8.(/!`Z!7YR@^?)TC>(/A`Z0[@```.,```'][.!1_
M6C$4?4`H.'SWZ!1\UN$4?7D#>#L```!__T@4?]Y!%'SGR!1\QL$4?+4K>'QE
M4WA\9%`X5W,H/G__J!1_WJ$4?V4H.%=K\`)78/"^?`!;>'SGF!1\QI$4?+$C
M>("!`ZB`H0.L?_^(%'_>@11]6U-X?`H;>'P&&#A4_2@^?.I0.%3K\+Y\I4@4
M?(1!%#N```!4Y_`"?__H%'_>X11]63-X@4$#L(.!`[A]?CMX@6$#M#M````[
M````?*78%'R$T11]*5@4?0A1%'RER!1\A,$4?'<;>#K```!_PP-X?]T`.%?G
M*#Y]*;@4?0BQ%'_C&#@XP```?'7K>(.A`[Q\I3@4?(0Q%#J```!7Y_`"5^/P
MOCU@RF(Y0```86O!UGQC.WA]*:@4?0BA%'QD\GA4IR@^?[U8%'^<410XP```
M?2DX%'T(,11\FRIX@($#P'P3`WA4J/`".D```%2@\+Z`H0/$?[V8%'^<D10[
M0```?*58%'R$411\`$-X?[W8%'^<T11_V?-X.P```'P(&GA5)R@^?*7(%'R$
MP10XP```?[TX%'^<,11]'TIX@0$#R(.!`]!5)_`".\```%4Y\+Z!(0/,?SD[
M>'RE^!1\A/$4?'<;>%>G*#Y_(P)X?2E8%'T(410XP```?*4X%'R$,11\>^IX
M5Z?P`CK```!7H_"^@Z$#U'TIN!1]"+$4.T```'^]6!1_G%$4?&,[>'TIV!1]
M"-$4?!4#>#J```!\9,IX5*<H/G^]J!1_G*$4.,```'TI.!1]"#$4?)\J>("!
M`]A4J/`".\```%2@\+Z`H0/<?`!#>'^]^!1_G/$4@\$#Z(/A`^Q\"!IX52<H
M/GRE6!1\A%$4.,```'^].!1_G#$4?1M*>($!`^!_,\MX52?P`CI```!5//"^
M@2$#Y'REF!1\A)$4.T```'TI6!1]"%$4?YP[>'REV!1\A-$4?'D;>#L```!_
M@P)X5Z<H/GTIR!1]",$4.,```'RE.!1\A#$4?'?J>%>G\`(ZP```5Z/POGQC
M.WA]*;@4?0BQ%'QDXGA4IR@^?_]8%'_>410XP```?2DX%'T(,11\FRIX@($#
M\'P5`WA4J/`".H```%2@\+Z`H0/T?_^H%'_>H10[0```?*58%'R$411\`$-X
M?__8%'_>T11_D^-X.D```'P(&GA5)R@^?*68%'R$D10XP```?_\X%'_>,11]
M'4IX@0$#^(/!!`!5)_`".X```%4W\+Z!(0/\?O<[>'REZ!1\A.$4?'D;>%?G
M*#Y^XP)X?2E8%'T(410XP```?*4X%'R$,11\>_IX5^?P`CL```!7X_"^@^$$
M!'TIR!1]",$4.T```'__6!1_WE$4?&,[>'TIV!1]"-$4?!4#>#J```!\9+IX
M5*<H/G__J!1_WJ$4.,```'TI.!1]"#$4?)TJ>("!!`A4J/`".X```%2@\+Z`
MH00,?`!#>'__Z!1_WN$4?`@:>%4G*#Y\I5@4?(11%#C```!__S@4?]XQ%'T;
M2GB!`000@\$$&'[SNWA5)_`".D```%4W\+Z!(004?*68%'R$D10[0```?2E8
M%'T(411^]SMX?*78%'R$T11\>1MX.P```'[C`GA7YR@^?2G(%'T(P10XP```
M?*4X%'R$,11\??IX5^?P`CN```!7X_"^@^$$'((,``1\8SMX?2GH%'T(X12!
M[```@BP`#'QDNGA4IR@^?_]8%'_>410XP```?2DX%'T(,11\FRIX@($$('P5
M`WA4J/`".H```%2@\+Z`H00D?_^H%'_>H10[0```?*58%'R$411\`$-X?__8
M%'_>T11^\[MX.D```'P(&GA5)R@^?*68%'R$D10XP```?_\X%'_>,11]'4IX
M@0$$*(/!!#!5)_`".X```%4W\+Z!(00L?O<[>'REZ!1\A.$4?'D;>%?G*#Y^
MXP)X?2E8%'T(410XP```?*4X%'R$,11\>_IX5^?P`CL```!7X_"^@^$$-'TI
MR!1]",$4.T```'__6!1_WE$4?&,[>'TIV!1]"-$4?!4#>#J```!\9+IX5*<H
M/G__J!1_WJ$4.,```'TI.!1]"#$4?)TJ>("!!#A4J/`".X```%2@\+Z`H00\
M?`!#>'__Z!1_WN$4?`@:>%4G*#Y\I5@4?(11%#C```!__S@4?]XQ%'T;2GB!
M`01`@\$$2'[SNWA5)_`".D```%4W\+Z!(01$?*68%'R$D12"3``4.T```()L
M`!Q]*5@4?0A1%'[W.WA\I=@4?(31%'QY&W@[````?N,">%?G*#XXP```?2G(
M%'T(P11\I3@4?(0Q%'Q]^GA7Y_`".X```%?C\+Z#X01,?&,[>'TIZ!1]".$4
M5*<H/GQDNGA__U@4?]Y1%#C```!]*3@4?0@Q%'P5`WA\FRIX@($$4%2@\+XZ
M@```5*CP`H"A!%1__Z@4?]ZA%(*,`"0[0```?6LH%'U*(11\"$-X?__8%'_>
MT11^Y[MX.,```%4D*#Y]:S@4?4HQ%'T%&GA^_R(4?*=*>#K````XP```5N4H
M/GSG6!1\QE$45LHH-%4@\+Y5)O`"?*E3>'UG2A0Y0```?6N`%'U*>12"#``(
M.X```'P=,WA^]X@4?M:!%((L`!`[P```?1]#>'^]D!1_G(D4@DP`&#B```!\
M91MX?_^8%'_>D12";``@.2```)$L``!\I:`4?(29%)%L``21+``(DNP`#)$L
M`!"3K``4D2P`&)/L`!R1+``@D*P`)(*!!%R"HH_X?I2J>3J@``!`@@!<@`$$
MM('!!&B!X01L@@$$<'P(`Z:"(01T@D$$>()A!'R"@02`@J$$A(+!!(B"X02,
M@P$$D(,A!)2#0028@V$$G(.!!*"#H02D@\$$J(/A!*PX(02P3H``($@`)Z4L
M`P``08(!,)0A_]`](!`"?`@"II-A`!R#:;$@D`$`-)-!`!@OFP``DX$`().A
M`"23P0`HD^$`+$&>`(B)(P``+XD``$&>`.@KB0`].\```$&>`"!\?AMXC3X`
M`2\)```KB0`]09H`"$">__!_P_!0@_L``"^?``!!G@!(?)HC>'Q\&WA_?=MX
M8````&````!_X_MX?X3C>'_%\WA(`"H5+X,``$">`!!]/_"N+XD`/4&>`$"'
M_0`$+Y\``$">_]2``0`T@T$`&#A@``"#80`<@X$`('P(`Z:#H0`D@\$`*(/A
M`"PX(0`P3H``(&````!_N^A0.'X``7^]%G!\?QH4D[H``(`!`#2#00`8@V$`
M'(.!`"!\"`.F@Z$`)(/!`"B#X0`L."$`,$Z``"`[P```2___0#A@``!.@``@
M8````)0A_]!\"`*FD\$`*)/A`"R0`0`T?'\;>#_`$`*!(H_XD2$`'#D@``!_
MX_MX.($`&$S&,8)+__Z-+X,``$&>`$R!00`8@1ZQ(%5*$#I]*%(4A.D`!"^'
M``!\Z%$N09[_S(5)``0OB@``D4G__$">__1_X_MX.($`&$S&,8)+__Y%+X,`
M`$">_[R!00`<@2*/^'U*2GDY(```0((`'(`!`#2#P0`H@^$`+#@A`#!\"`.F
M3H``($@`):U@````8````)0A_\!\"`*FDX$`,)`!`$23H0`TD\$`.)/A`#R3
M`0`@DR$`))-!`"B380`L?'\;>(DD``!I/0`]([T``'^D`92!(H_XD2$`'#D@
M``!_H^MX2``FL3B!`!A\?!MX?^/[>$S&,8)+__V=?'X;>4&"`71(`":1?YP8
M0$"=`3B#80`8/T`0`E=[$#J)/P``+XD``$&>`@0KB0`]09X!_'_J^WA(```8
M8````&````!@````*XD`/4&>`!"-*@`!+XD``$">__!]7U!0.'P``H/:L2!\
M8U(42``EO2^#``!\?MDN09X!R(D_``"!00`8@1JQ(%5*$#HOB0``?4A0+IDJ
M``!!G@`X*XD`/4&>`#!_Z/MX2```&&````!@````8````"N)`#U!G@`4C2@`
M`9TJ``$OB0``0)[_[#D@`#TX??__F2H``&````!@````8````(TC``&=*@`!
M+XD``$">__0X8```@4$`'($BC_A]2DIY.2```$""`3R``0!$@P$`((,A`"2#
M00`H?`@#IH-A`"R#@0`P@Z$`-(/!`#B#X0`\."$`0$Z``"!@````8````#A]
M__\Y7O__8````&````"-(P`!G2H``2^)``!`GO_T2___D&````!@````8```
M`#]`$`*#&K$@@3@``"^)``!!G@"L?PK#>#O```!@````A2H`!#O>``$OB0``
M0)[_]#B>``)4A!`Z/4`0`H$JL40OB0``09X`/'\#PWA(`"15+X,``)!ZL2!!
MG@!P5]L0.CD^``$Y0```52D0.GU#22Z3P0`82__^-&````!@````.2```7R#
M(WB1*K%$2``D)7QY&WE!@@`T5]L0.G\$PWA_9=MX2``BG9,ZL2!_(\MX2___
ML#E```!+__XP.(``"#O```!+__]T.&#__TO__KA(`"+Q8````&````!@````
ME"'_8'P(`J:3H0"4D`$`I)-A`(R3@0"0D\$`F)/A`)Q\?1MY@2*/^)$A`'PY
M(```08(`$(D]```OB0``0)X`1(%!`'R!(H_X?4I*>3D@``!`@@%(@`$`I(-A
M`(R#@0"0@Z$`E'P(`Z:#P0"8@^$`G#@A`*!.@``@8````&````!(`"71?'X;
M>4&"_[@_8!``.WML"'_#\WA(`"4Y+`,``$&"`*")(P`3+XD`+D&>`+0[XP`3
M?Z/K>$@`(XE\?!MX?^/[>$@`(WU\?!H4.&,``D@`(P$X@``!.*#__W]FVWA_
MI^MX?'P;>'_H^WA,QC&"2``CD3A@``-_A.-X.*$`$$@`)0$O@___?X/C>$&>
M`!2!(0`@52D$)BN)0`!!G@!T2``AX7^#XWA(`"%)?\/S>$@`)*$L`P``0(+_
M;&````!_P_-X2``D_7^CZWA(`"%E2__^\&````!@````8````(DC`!0OB0``
M09[_+"N)`"Y`GO]`B2,`%2^)``!!GO\82___,&````!@````8````$O__G%+
M__^02``A26````"4(?_@?`@"II/A`!P_X!`"@'^Q*)`!`"23H0`4D\$`&$@`
M)%&!(P"`@'^Q*(.I``1(`"1!B2,`98!_L2A5/@9^2``D,8$C``2!*0`052F$
M,'_)2WBQ/0`"@'^Q*$@`)!6!(P"`@'^Q*(/)``1(`"0%/(`0`#B@```XA&\8
M2``B59!^`!R`?[$H2``CZ8$C`("`?[$H@\D`!$@`(]F!(P6X@'^Q*)$^`"!(
M`"/)@2,`@(!_L2B#R0`$2``CN3E```"!(P#\+XD``$&>`!2`?[$H2``CH8$C
M`/R!20!PD5X`)(!_L2@[P```2``CB8$C`("`?[$H@2D`!)/)`"A(`"-U@2,`
M@(!_L2B!*0`$D\D`&$@`(V&!(P"`@'^Q*(/I``1(`"-1@2,"&)$_`"R``0`D
M@Z$`%(/!`!B#X0`<."$`('P(`Z9.@``@8````&````"4(?_@?`@"II/A`!P_
MX!`"D\$`&'Q^&WB`?[$HD`$`)$@`(P%_Q/-X.*,!"#A@``-(`",!+X,``$&>
M`"B``0`D@\$`&#A@``"#X0`<."$`('P(`Z9.@``@8````&````"`?[$H2``B
MO8$C`1A5*00F*XE``$&>`""`?[$H2``BI8$C`1A5*00F;2K__R^*H`!`GO^L
M?\/S>#B```)(`"'E@`$`)(/!`!B#X0`<."$`('P(`Z9\8P`T5&/9?DZ``""4
M(>_0.*`/_WP(`J:3H1`DD\$0*)`!$#23X1`L?'X;>#Q@$`!\G2-X.&-L$#B!
M`!R!(H_XD2$0'#D@``!(`!]%+`,``$"!`)P[X___.4$0('TJ^A2)*>_\+XD`
M`$&>`'1\?QMX.&$`'#B``"]_Y?MX2``@X2^#``!!G@!H/2`0`H!IL2A(`"'=
M?\3S>#BA`!Q_YOMX2``A;8$A$!R!0H_X?2E2>3E```!`@@!4@`$0-(.A$"2#
MP1`H@^$0+#@A$#!\"`.F3H``(&````!@````+Y\``$">_Y!@````8````#T@
M$`*`:;$H2``A>7_$\WA_I>MX2``>G4O__Z!(`!XUE"'_\#T@$`)\"`*F@&FQ
M*)`!`!1(`"%-@`$`%#R`$``\H!``/,`0`'P(`Z8XA&P@.*5F(#C&:W0X(0`0
M2``?M)0A_^!\"`*FD^$`'#_@$`*`?[$HD`$`)$@`(0E+__^E@'^Q*$@`(/V`
M`0`D/,`0`(/A`!P\@!``/*`0`#C&;QA\"`.F.(1L/#BE7K!\QS-X.0```#@A
M`"!(`"`88````)0AW]!\"`*FD\$@*)`!(#23X2`L@2*/^)$A(!PY(```2``>
M,3S`$``]`!``?&<;>#B```$X80`4.*`0`3C&;%0Y"&Q@3,8Q@D@`'NDO@P``
M09P`<#AA`!0X@1`8.*`0`$@`'8%\?AMY08``6#A^``%(`!X1?'\;>4&"`$@X
M@1`8?\7S>$@`'*TY(```?^/[>'T_\:Z!02`<@2*/^'U*2GDY(```0((`)(`!
M(#2#P2`H@^$@+#@A(#!\"`.F3H``(#A@``!+___02``<R6````"4(?_P."$`
M$$O__RA@````E"'OL'V``"9\"`*FDV$0/).A$$20`1!4D^$03)&!$""2H1`D
MDL$0*)+A$"R3`1`PDR$0-)-!$#B3@1!`D\$02'Q]&W@\8!``?)\C>#AC;&@X
M@0`8@2*/^)$A$!PY(```3,8Q@DO_]*TX@``O?'L;>'^CZWA(`!U]+X,``$&>
M`'0\8!``?Z3K>#AC;'1,QC&"2__V@7^CZWB!01`<@2*/^'U*2GDY(```0((!
MM(`!$%2!@1`@@J$0)(+!$"A\"`.F@N$0+(,!$#!]@($@@R$0-(-!$#B#81`\
M@X$00(.A$$2#P1!(@^$03#@A$%!.@``@?Z/K>#^`$`!(`!T9.YQLA"X;``!_
MA.-X?'D;>'_C^WA(`!Y!?'X;>4&"_V@^X!``/P`0`#J@```^P!``.SD``3KW
M;(@[&&R0/T`0`F*U@``[X```8````&````!@````B3X``"^)``!`G@`(.]9L
M9$&2`!A_8]MX?\3S>$@`&I4O@P``09X`G'_#\WA(`!R5?+X:%(DE__\OB0`O
M0)X`&)_E__\X8___B47__R^*`"]!GO_P?7D:%"^+#_]!G?[4.(```3B@$`!^
MYKMX?\?S>'\(PWA_J>MX.&$`'$S&,8)(`!R!@'JQ*$@`'@DX@0`<.*,!"#A@
M``-(`!WI+X,``$">`!R`>K$H2``=Z8$C`1A5*00F?XFH`$&>`"`X8```?X3C
M>$@`'3TO@P``?'X;>$">_S!+__Y<.&$`'#B```%(`!T1+X,``$">_]0\8!``
M.($`'#AC;'1,QC&"2__TQ3AA`!Q(`!Q-2__^0$@`&E64(?_PB2,``"^)``!!
MG@!`.4,``4@``!Q@````8````(DJ```Y2@`!+XD``$&>`"`KB0`O0)[_[(DJ
M``!]0U-X.4H``2^)``!`GO_H."$`$$Z``"!@````8````&````"4(?_@?`@"
MII/A`!Q\?QMYD`$`))/!`!A!@@#XB]\``"^>``!!G@#L2``;*3AC__]\OQH4
M?Y\H0$"<`#Q]/QBN+XD`+T">`1Q]/RA0?2D#ID@``!Q@````8````&````")
M)0``+XD`+T">`/@XI?__0@#_\'^?*$!!G@"(.27__W^?2$!]/RA0?2D#ID&=
M`2POG___0+X`&$@``2!@````B24``"^)`"]`G@`,.*7__T(`__!\ORA0.24`
M`BN)$`!!G0"`/&`0`G_D^W@X8[%$.*4``3O#``0XP!``?\/S>$@`&V&``0`D
M?\/S>(/A`!R#P0`8."$`('P(`Z9.@``@*YX`+T">`)1@````8````#A@``)(
M`!G-+`,``$&"`"0Y("X`L2,``(`!`"2#P0`8@^$`'#@A`"!\"`.F3H``((`!
M`"2#P0`8.&```(/A`!PX(0`@?`@#IDZ``"!@````.27__W^?2$!]/RA0?2D#
MID&=`%0OG___0+X`%$@``$B))0``+XD`+T&>_O0XI?__0@#_\$O__N"``0`D
M@\$`&#Q@$`"#X0`<.&-LD'P(`Z8X(0`@2``:+#D@``%]*0.F2__^[#D@``%]
M*0.F2___P)0A_[`\@!``?`@"ICB$:W0XH``B.(0`#)`!`%23@0!`DZ$`1)/!
M`$B3X0!,.&$`&#_@$``_P!``._]LO#O>;&@_@!``/Z`0`#N<;-@[O6SD@2*/
M^)$A`#PY(```2``793Q@$``X8VR43,8Q@DO_\54\8!``.&-LH$S&,8)+__%%
M/&`0`#AC;*A,QC&"2__Q-3Q@$``X8VRT3,8Q@DO_\25_X_MX3,8Q@DO_\1D\
M8!``.&-LS$S&,8)+__$)?\/S>$S&,8)+__#]?X/C>$S&,8)+__#Q?Z/K>$S&
M,8)+__#E/&`0`#AC;/!,QC&"2__PU3Q@$``X8VQT3,8Q@DO_\,4\8!``.&-L
M_$S&,8)+__"U/&`0`#AC;0A,QC&"2__PI3Q@$``X@0`4.&-M%$S&,8)+_^]1
M?&0;>4&"`!!_H^MX3,8Q@DO_\3T\8!``.($`%#AC;2A,QC&"2__O*7QD&WE!
M@@`4/&`0`#AC;3Q,QC&"2__Q$3Q@$``X@0`4.&-M2$S&,8)+_^[]?&0;>4&"
M`&1_P_-X3,8Q@DO_\.D\@!``?^/[>#B$;7A,QC&"2__PU8%!`#R!(H_X?4I*
M>3D@``!`@@"0@`$`5(.!`$"#H0!$@\$`2'P(`Z:#X0!,."$`4$Z``"!@````
M8````&`````\8!``.($`%#AC;5A,QC&"2__N@7QD&WE!@@`8?X/C>$S&,8)+
M__!M2___A&`````\@!``.&$`*3B$;6PXH``*2``9`2^#``!`GO]D?X/C>#B!
M`#-,QC&"2__P.4O__U!(`!718````&````!@````E"'_T'P(`J:3X0`LD`$`
M-#_@$`*`?[$8+X/__X$BC_B1(0`<.2```$&>`#B!00`<@2*/^'U*2GDY(```
M0((`<(`!`#2#X0`L."$`,'P(`Z9.@``@8````&````!@````/&`0`#B!`!@X
M8VS83,8Q@DO_[;$L`P``08(`*(DC```X8```+XD``$&>`!!I(P`P?&,`T%1C
M#_Z0?[$82___D#A@``"0?[$82___A$@`%164(?_P?`@"II`!`!1(`!452``4
M<2P#``!!@@`8@&,``(`!`!0X(0`0?`@#IDZ``"`X8```2___[&````!@````
ME"'_H#T@$`!\"`*F.2EK=(%)`#"`B0`T@*D`.(#)`#R`Z0!`@0D`1)/!`%B3
MX0!<D`$`9),A`$2300!(DV$`3).!`%"3H0!4@2D`2'U?4WD[P0`@@6*/^)%A
M`#PY8```D4$`()"!`"20H0`HD,$`+)#A`#"1`0`TD2$`.$&"`(`\P!``/0`0
M`'Q\&W@[1FR(.VALA$@``"A@````8````'^$XWA(`!-M+X,``$&>`)2'_@`$
M+Y\``$&>`$1_X_MX.($`'$S&,8)+_^QI?'T;>4&"`!")70``+XH``$">_\1_
MX_MX?X3C>$S&,8)+_^Y%A_X`!"^?``!`GO_$@2$`/(%"C_A]*5)Y.4```$""
M`(R``0!D@R$`1(-!`$B#80!,?`@#IH.!`%"#H0!4@\$`6(/A`%PX(0!@3H``
M(&````!_@^-X2``4[7QY&WA_H^MX2``4X7QY&A0X8P`"2``493B```$XH/__
M?T;3>'^'XWA\>1MX?VC;>'^IZWA,QC&"2``4\7_C^WA_),MX3,8Q@DO_[:%+
M__\<2``3.6`````\`/__?"P+>&``?K`](!``?"$!;GP(`J8Y*6MT@6D`8("I
M`&2`R0!H@.D`;($)`'"!20!TD`P`!(`)`%R2C/_0DLS_V)+L_]R3#/_@DRS_
MY)/,__B3[/_\D@S_P)(L_\223/_(DFS_S)*L_]233/_HDVS_[).,__"3K/_T
M/\`0`(/I`%B"R0!,?'@;>(+I`%"#*0!4.]YL:#B!`!2!*0!X?\/S>#Z!``&"
MHH_XDK2!##J@``"3X0`PDL$`&)+A`!R3(0`@D`$`-)%A`#B0H0`\D,$`0)#A
M`$21`0`DD4$`*)$A`"Q,QC&"2__JJ7Q_&WE!@@`0B3\``"^)``!`G@4$2__]
M(3OA`"`[(0`4?'<;>4&"`GQ^X[MX2``3>51C"#PX8P`!2``2_8CW```OAP``
M?'D;>$&>`$0^P!``?'\;>#K6;81@````8````&````!_X_MX.(```3B@__]^
MQK-X3,8Q@D@`$VV,]P`!._\``B^'``!`GO_<.^&!$#K!`!2$?W\@+X,``$">
M`!1(``!4A'\`!"^#``!!G@!(?L2S>$S&,8)+_^GM?'<;>4&"_^2)-P``+XD`
M`$&>_]A+__&%+X,``$&>_\Q^X[MX2``357QV&WE`@@"`8````&````"#X0`8
M+Y\``$&>`=B)/P``.N```2^)``!`G@`\2``!Q#E```!6Z1`Z84J!$'U*"A1]
M*DH4/2G__X/I?P@OGP``09X!H(D_```Z]P`!+XD``$&>`9!_X_MX2__Q"2^#
M``!!GO_`?^/[>$@`$ME\=AMY08+_L'[#LW@^@!``2``2-3J4;)!\?QMX?R/+
M>$@`$B5\?QH4.^,$!'_C^WA(`!&E/,`0`#T@$``X@``!.*#__WQU&W@XQFV,
M?L>S>'Z(HW@Y*6V8?RK+>$S&,8)(`!(E?J.K>#B``<!(`!)9+X/__T&>`1`_
M(!`"@'FQ*$@`$Y5^I*MX.*,!"#A@``-(`!.5+X,``$&>`2P](!`"@-@``#R@
M$`"`:;$D.(```3BE;B!^IZMX3,8Q@D@`$IDX8```/H$``8*T@0R"@H_X?K6B
M>3J```!`@@A4@6$``(`+``2""__`@BO_Q()+_\A\"`.F@FO_S(*+_]""J__4
M@LO_V(+K_]R#"__@@RO_Y(-+_^B#:__L@XO_\(.K__2#R__X@^O__'UA6WA.
M@``@8````$@`$:%\=QMY0(+]C(1_``0O@P``09X"?'\DRWA,QC&"2__G\7QI
M&WE!@O_DB2D``"^)``!!GO_82___R&`````ZP```2__^D&````!@````2``1
M<8$#```OB``109[^Z#T@$`*`V```/*`0`(!IL20X@``!.*5MH'ZGJWA,QC&"
M2``1H3A@``!+__\(8````(!YL2A(`!)-@2,!&%4I!"8KB4``0)[^Q(!YL2A(
M`!(U@N,!($@`#PU_EQ@`0)[^K(!YL2A(`!(=@2,!&%4I!?XKB0'`0)[^E'_C
M^WA(``_%.($`%'QW&W@\8!``.&-O;$S&,8)+_^<=+X,``$&>!O2#^```2``0
MG7QD&WA_X_MX2__Q\7QY&WE!@@;8?R/+>$@`#_$O@P`#?'\;>$"=`$0X8__\
M/(`0`'QY&A0XA&W<2``-P2^#``!`G@`H+Y\`!$&>!:1_^?H4B3__^R^)`"]!
MG@648````&````!@````2__X@2^#``!`G@`<?R/+>#B```!,QC&"2``/J7QR
M&WE`@@$0/(`0`#Q@$``XA&UX.&-LV$S&,8)+_^AI2``.Q3^@$``\P!``.[UO
M&#B```%\:1MX.*#__W[CNW@XQFW\?J>K>'Z(HWA_JNMX/X`0`$S&,8)(``]M
M.^```#N<;@Q(``!48````&````!@````2``/P8$C```OB0`10)X`3$@`#F&3
MH0`(._\``3B```$XH/__?&D;>'^&XWA^X[MX?J>K>'Z(HWA_ZOMX3,8Q@D@`
M#Q%^X[MX.(`!P$@`#T4O@___09[_K'ZCJWA(``SE?N2[>'_#\WA,QC&"2__G
MI7[CNWA+__AM?N.[>$O__11+__AA?^/[>$@`#QE+__T$/N`0`#A@``TZ]VU\
M2__["#B@__\XP/_N..```D@`#;5^0Y-X.($!##B@``9(``Q5B2$!#"^)``!`
MG@`0B2$!#2^)`$-!G@24?D.3>#B@```XP```..```$@`#7D](&=%.0```&$I
M(P&1`0!(D2$`3#T@[\UA*:N).0```)$A`%0]()BZ82G<_I$!`%"1(0!</2`0
M,F$I5'8Y````D2$`9#T@P])A*>'PD0$`6#D````Y0```.6```)$!`&"1(0!L
M.0```#D@``"1`0!HD4$`<)%A`'2100!XD6$`?)$A`,`Z(```.L$`@#IA`$A@
M````.*```'Y#DW@X@0$,8*6``$@`"X%\>!MY0($!8(%!`'!_!_YP5PD??H%A
M`'14_!@X5QT8."N*``!]/.-X?3U8%'T<411!G0,<+XH``$">``Q_BTA`09T#
M#(%!`'B!80!\@&$`P%3H&#A7&Q]^?1O;>%3Z'WXO@P``?6O8%'U*T122(0!P
MD2$`=)%!`'B180!\09X"P"$C`$!_$,-X?YA(`$"=``A],$MX?',:%#B!`0PX
M8P`X?@6#>$@`"QF!(0#`?3!*%"^)`$"1(0#`0)[_-#B!`0Q^8YMX?Q#`4'X$
M@A1+_[RQ8````&````!@````+Y@`/T"=`%!_&<-X?A^#>'_D^W@XH`!`?L.S
M>#LY_\!(``K!?F.;>#O_`$!+_[QU+YD`/T&=_]P[&/_`5PG1OAU)_\`Y*0`!
M52DP,GX02A1_&%(4?P7#>'X$@W@XP`!(?L.S>$@`"^TXH```?D.3>#B!`0Q@
MI8``DP$`P$@`"B5\>!MY08'^J'Y#DWA(``X%@^$`=#E!@1"#H0!\5^7NOCDE
M``$OB0`X?2HJ%#E`_X"927]P09T"$#E!@1`X@```?&HJ%""E`#<X8W]Q2``,
M15>E1CY7IH0^5Z?"/E?H1CY7ZH0^5^G"/CAA`$B8H0"XF,$`N9CA`+J;H0"[
MF0$`O)E!`+V9(0"^F^$`OTO_NY6`P0!4@*$`3($!`%R!00!D@2$`;%361CY4
MIT8^51S"/E5=1CY57X0^5+*$/E2SPCY4V(0^5-G"/E4:1CY5&X0^54#"/E4K
M1CY5(X0^523"/IK!`-`^P!``FX$`UINA`-B;X0#9F.$`S)I!`,V:80#.F*$`
MSYL!`-&;(0#2F,$`TYM!`-2;80#5F0$`UY@!`-J900#;F6$`W)AA`-V8@0#>
MF2$`WSOA`.`[H0#,.X$!"#K6;81(```08````&````",_0`!?^/[>#B```$X
MH/__?L:S>#O_``),QC&"2``*]7^?X$!`GO_</,`0`#U`$``Y8```.*#__SC&
M;>Q^IZMX?HBC>#DA`.`Y2F\8.(```7[CNWB980$(3,8Q@D@`"K5^HZMX2``(
MG7[DNWA_P_-X3,8Q@DO_XUU^X[MX2__T)7[CNWA+__C,8````&`````Z`0$,
M2__]G&````!@````@4$`>(%A`'PQ:P`!?4H!E$O__/"#^``$+Y\``$&>^G1_
MX_MX2``*#2N#``-`G?ID.&/__#R`$`!\?QH4.(1MY$@`!^$O@P``0)[Z2'_Y
M^WA+__I`.($`2'QD*A0@I0`_.(```#AC`#E(``HY.&$`2$O_N<$X80"`.(``
M`#B@`#A(``HA2__]W(DA`0XOB0!!0)[[:(DA`0\OB0!#0)[[7(DA`1`OB0!(
M0)[[4(DA`1$OB0!%0)[[1#C`_\8XX``".*#__WY#DWA(``BY.($!#'Y#DW@X
MH``I2``'63S`$``]0!``?N.[>#B```$XH/__.,9M['ZGJWA^B*-X.2$!##E*
M;QA,QC&"2``):4O_^FR#.```2__Y*$@`![E@````E"'_L'P(`J:3(0`TD`$`
M5)+A`"R3`0`PDT$`.)-A`#R3@0!`DZ$`1)/!`$B3X0!,/R`0`H!YL2B!(H_X
MD2$`'#D@``!(``J=.2```3B!`!B9(P!A/&`0`#AC;+Q,QC&"2__?L2P#``!!
M@@`0B2,``"^)`#%!G@)L2__O&8!YL2@_H!`".[VQ1$@`"ED\@!``.*```3B$
M;G0XP``+2``(%2P#``!!@@#@@3T0!(%#`!`OB0`!@TH`&$"=`,P_8!`"/P``
M(#O````[X``!.WNQ*&,8!`!(```T8````&````"`B``0?N.[>$@`!AF!/1`$
M+X,``$">`(0[_P`!.]X``7^)^`!`G0!T@'L``$@`"=5_1--X?\7S>#C```!(
M``E%?'P;>4&"`AR!'```@/T0"%?J$#J!*``(?N=0+G\)2#@KB00`09[_G(![
M``!(``F5@)P``#B@```XP``"2``&Q7QD&WA^X[MX2``%F8$]$`0O@P``09[_
MA#E)__]_BO``09X!<(!YL2@_P!`"2``)53R`$``XH``!.(1N?#C```-(``<1
M?'\;>4&"`#2`?K$H2``),8$_`!`\H!``.*5N@(")``!(``9-@3\`$($I``"!
M*0`(=2H`0$""`GR`>;$H/^`0`D@`"/T\@!``.*```3B$;H@XP``#2``&N7Q^
M&WE!@@`X/&`0`#B!`!@X8VQT3,8Q@DO_W?U\?!MY@'^Q*$&"`=!(``B]@3X`
M$'^%XWB`B0``2``%W8!YL2A(``BE.2```#B!`!B9(P!A/&`0`#AC;&A,QC&"
M2__=N2^#``!\?QMXD'T0#$&>`/@X@`'`2``'(2^#`!%\9AMX09X`$#DC``$K
MB0`!09T!^($A`!R!0H_X?2E2>3E```!`@@'@@`$`5(+A`"R#`0`P@R$`-'P(
M`Z:#00`X@V$`/(.!`$"#H0!$@\$`2(/A`$PX(0!03H``(&````!@````8```
M`(DC``$OB0``09[]E$O__8POB0`!0)W^D#O@``%(```48````&````!@````
M8````(![```[_P`!2``'R7]$TWA(``1!@3T0!'^)^`!!G?_D2__^5&````!@
M````8````($]$`0Y2?__?XKP`$">_CA+__^@8````&````!@````@'T0"$O_
M\1TO@P``D'T0#$&>`/R!/@`0/0``(&$(!`"!20``@2H`"'T)2#@KB00`0)X`
MH(!J`!"#_1`(?^3[>$@`!%&!/@`0/0``((/_``!A"`0`@4D``'Q]&WB!*@`(
M?0E(."N)!`!`G@!$@*H`$#Q@$`!_Y/MX.&-NL'^FZWA,QC&"2``%?6````!@
M````2``&\8%>`!"!/1`(@&H``(")``!+_^1]2__^,(!YL2A(``;1@3X`$#B@
M```XP``"@(D``$@``_U\91MX2___I#T@$`*`:;$H2``&J8$^`!`XH```.,``
M`H")``!(``/52___2(!^L2A(``:)@3\`$(")``!(``6-2__]=#Q@$``X8VZ,
M3,8Q@D@`!.E(``,U@3T0"#Q@$`!_Y?MX.&-NV(")``!,QC&"2``$R6````"4
M(?_@?`@"II/!`!B3X0`<D`$`)'Q^&WA+_^D)B2,``'Q_&W@OB0``09X`1#E#
M``%(```@8````&````!@````B2H``#E*``$OB0``09X`("N)`"]`GO_LB2H`
M`'U?4W@Y2@`!+XD``$">_^A+_^SE+X,``$&>`#`OG@``09X`*(D^```OB0``
M09X`'#R`$`!_X_MX.(1MF$@``;E_GQ@`09X`'(`!`"2#P0`8@^$`'#@A`"!\
M"`.F3H``((`!`"2#X0`<?\/S>(/!`!@X(0`@?`@#IDO_WUQ@````8````)0A
M_^!\"`*FD^$`'#_@$`*`?[$HD`$`)$@`!4DX@/__2``"H8!_L2A(``4Y@`$`
M)(/A`!P\@!``.(1%(#B@``!\"`.F."$`($@`!.@`````E"'_\'P(`J9"GP`%
MD\$`")`!`!1_R`*F/]X``CO>RD"!/H``+XD``$&>`""`R0``2``"48`!`!2#
MP0`(."$`$'P(`Z9.@``@.,```$O__^24(?_0?`@"ID*?``63P0`HDR$`%'_(
M`J:300`8DV$`').!`""3H0`DD^$`+)`!`#1\>1MX?)HC>'R[*W@_W@`".^``
M`#O>R?1+_ZZ%@3Z`!(.>@`!_B>!0.ZG__'^<%G%!@@`T8````&````!@````
MA3T`!'\CRWA_1--X?V7;>'TI`Z8[_P`!3H`$(7^?X$!`GO_@@`$`-(,A`!2#
M00`8@V$`''P(`Z:#@0`@@Z$`)(/!`"B#X0`L."$`,$Z``"!.@``@````````
M````````/6`0`H%KL`!]:0.F3H`$(#U@$`*!:[`$?6D#IDZ`!"`]8!`"@6NP
M"'UI`Z9.@`0@/6`0`H%KL`Q]:0.F3H`$(#U@$`*!:[`0?6D#IDZ`!"`]8!`"
M@6NP%'UI`Z9.@`0@/6`0`H%KL!A]:0.F3H`$(#U@$`*!:[`<?6D#IDZ`!"`]
M8!`"@6NP('UI`Z9.@`0@/6`0`H%KL"1]:0.F3H`$(#U@$`*!:[`H?6D#IDZ`
M!"`]8!`"@6NP+'UI`Z9.@`0@/6`0`H%KL#!]:0.F3H`$(#U@$`*!:[`T?6D#
MIDZ`!"`]8!`"@6NP.'UI`Z9.@`0@/6`0`H%KL#Q]:0.F3H`$(#U@$`*!:[!`
M?6D#IDZ`!"`]8!`"@6NP1'UI`Z9.@`0@/6`0`H%KL$A]:0.F3H`$(#U@$`*!
M:[!,?6D#IDZ`!"`]8!`"@6NP4'UI`Z9.@`0@/6`0`H%KL%1]:0.F3H`$(#U@
M$`*!:[!8?6D#IDZ`!"`]8!`"@6NP7'UI`Z9.@`0@/6`0`H%KL&!]:0.F3H`$
M(#U@$`*!:[!D?6D#IDZ`!"`]8!`"@6NP:'UI`Z9.@`0@/6`0`H%KL&Q]:0.F
M3H`$(#U@$`*!:[!P?6D#IDZ`!"`]8!`"@6NP='UI`Z9.@`0@/6`0`H%KL'A]
M:0.F3H`$(#U@$`*!:[!\?6D#IDZ`!"`]8!`"@6NP@'UI`Z9.@`0@/6`0`H%K
ML(1]:0.F3H`$(#U@$`*!:["(?6D#IDZ`!"`]8!`"@6NPC'UI`Z9.@`0@/6`0
M`H%KL)!]:0.F3H`$(#U@$`*!:["4?6D#IDZ`!"`]8!`"@6NPF'UI`Z9.@`0@
M/6`0`H%KL)Q]:0.F3H`$(#U@$`*!:["@?6D#IDZ`!"`]8!`"@6NPI'UI`Z9.
M@`0@/6`0`H%KL*A]:0.F3H`$(#U@$`*!:["L?6D#IDZ`!"`]8!`"@6NPL'UI
M`Z9.@`0@/6`0`H%KL+1]:0.F3H`$(#U@$`*!:["X?6D#IDZ`!"`]8!`"@6NP
MO'UI`Z9.@`0@/6`0`H%KL,!]:0.F3H`$(#U@$`*!:[#$?6D#IDZ`!"`]8!`"
M@6NPR'UI`Z9.@`0@/6`0`H%KL,Q]:0.F3H`$(#U@$`*!:[#0?6D#IDZ`!"`]
M8!`"@6NPU'UI`Z9.@`0@/6`0`H%KL-A]:0.F3H`$(#U@$`*!:[#<?6D#IDZ`
M!"`]8!`"@6NPX'UI`Z9.@`0@/6`0`H%KL.1]:0.F3H`$(#U@$`*!:[#H?6D#
MIDZ`!"`]8!`"@6NP['UI`Z9.@`0@/6`0`H%KL/!]:0.F3H`$(#U@$`*!:[#T
M?6D#IDZ`!"`]8!`"@6NP^'UI`Z9.@`0@/6`0`H%KL/Q]:0.F3H`$(#U@$`*!
M:[$`?6D#IDZ`!"`]8!`"@6NQ!'UI`Z9.@`0@/6`0`H%KL0A]:0.F3H`$(#U@
M$`*!:[$,?6D#IDZ`!"!(``$02``!#$@``0A(``$$2``!`$@``/Q(``#X2```
M]$@``/!(``#L2```Z$@``.1(``#@2```W$@``-A(``#42```T$@``,Q(``#(
M2```Q$@``,!(``"\2```N$@``+1(``"P2```K$@``*A(``"D2```H$@``)Q(
M``"82```E$@``)!(``",2```B$@``(1(``"`2```?$@``'A(``!T2```<$@`
M`&Q(``!H2```9$@``&!(``!<2```6$@``%1(``!02```3$@``$A(``!$2```
M0$@``#Q(```X2```-$@``#!(```L2```*$@``"1@````8````&````!@````
M8````&````!@````8````#V`$`(]:_``@`RO^#EKEB!\"0.F?`M:%(&,K_Q]
M8%H43H`$(&````!@````8````&````!@````8````&````"4(?_P?`@"II`!
M`!23P0`(0I\`!7_(`J:``0`4?`@#IH/!``@X(0`03H``(``````0`C$<$``3
MX!``9-`0`&60``(``7!E<FQX<VDN8P```%]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@`````!``;TP0`&]<$`!O9!``;VP0`&]T$`!OB``````0
M`&]$$`!L9``````0`&T\$`!M0!``;S@0`&QL$`!O0``````0`&\D$`!O+```
M``!9@```````````````````0<____^````E<R\E<P```"]P<F]C+W-E;&8O
M97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI0
M05(Z.D)/3U0`````+W!R;V,O)6DO)7,`97AE`"X```!005)?5$5-4`````!0
M05)?4%)/1TY!344`````.@```"5S)7,E<P``+P```%!%4DPU3$E"`````%!%
M4DQ,24(`4$523#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`4$%2
M7U-005=.140`4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%````
M4$%27T%21T,`````4$%27T%21U9?,```4$%27T=,3T)!3%]$14)51P````!0
M05)?1TQ/0D%,7U1-4$1)4@```%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-
M4`!005)?1TQ/0D%,7T-,14%.`````%!!4E]#3$5!3CT``#$```!365-414T`
M`"4P,G@`````)7,E<R5S)7,`````<&%R+0`````E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*``!P
M87)L`````"YP87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,`
M```E<R5S=&5M<"TE=2TE=25S`````"5S.B!P<FEV871E('-U8F1I<F5C=&]R
M>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO
M=7(@;W!E<F%T:6]N*0H``$%21U8`````&````'!E<FP`````,````%5N86)L
M92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!E>&5C=71I;VX@
M;V8@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M`````"UE```M+0``55-%4@````!54T523D%-10````!414U01$E2`%1-4``O
M=&UP`````$Q$7TQ)0E)!4EE?4$%42`!,24)0051(`$Q)0E)!4EE?4$%42```
M``!$64Q$7TQ)0E)!4EE?4$%42````%-(3$E"7U!!5$@``&5V86P@)V5X96,@
M+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R
M=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@
M*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H
M:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@
M6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*
M>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@
M+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@
M)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@
M)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N
M9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N
M86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF
M(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I
M;FET7V5N=B@I.PII9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%
M3E9[4$%27T%21U9?,'T@*2!["D!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=6
M7R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B0P(#T@)$5.5GM0
M05)?05)'5E\P?3L*?0IE;'-E('L*9F]R("AK97ES("5%3E8I('L*9&5L971E
M("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*?0I]"FUY("1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^
M("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]
M/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@
M)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<
M7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H
M*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?
M7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O
M<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["G-E96L@7T9(+"`M."P@
M,CL*<F5A9"!?1D@L("1B=68L(#@["FQA<W0@=6YL97-S("1B=68@97$@(EQN
M4$%2+G!M7&XB.PIS965K(%]&2"P@+3$R+"`R.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<V5E:R!?1D@L("TQ,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D
M(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY
M("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D
M(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B
M=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F
M:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]
M?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S
M96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\
M*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH
M(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN
M*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("@D;W5T+"`D9FEL96YA;64I(#T@
M7W1E;7!F:6QE*"1E>'0L("1C<F,I.PII9B`H)&]U="D@>PIB:6YM;V1E*"1O
M=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O=70["F-H;6]D(#`W-34L
M("1F:6QE;F%M93L*?0HD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M
M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N
M86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO
M/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F
M:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*;W5T
M<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["F]P96X@;7D@)&]U="P@)SXG+"`D
M9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T
M("1B=68["F-L;W-E("1O=70["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U
M;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65]
M(#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN
M86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H
M<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F
M("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C
M:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U
M;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI
M<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[
M)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D
M14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2![
M"FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I
M;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH
M)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@*"1O=70L("1N
M86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["FEF
M("@D;W5T*2!["F)I;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&9I;&5N86UE
M+3Y[8G5F?3L*8VQO<V4@)&]U=#L*?0IO<&5N(&UY("1F:"P@)SPG+"`D;F%M
M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@
M(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN
M(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER
M92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@
M)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@
M;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@
M+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@
M)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<
M+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]
M"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S
M(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@
M)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!
M4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U
M<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)5
M1WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P
M=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L
M:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS
M("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D
M05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%2
M7T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@
M<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@
M>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L
M87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]
M"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H
M)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H
M)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2![
M"B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N
M9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q
M.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R
M(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H
M)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I
M.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[
M)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@
M0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S
M:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E
M;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R
M)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD[
M"B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@
M*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`]
M(&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H
M)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A
M(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O
M;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E
M*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q0
M05(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H
M*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H
M*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F
M:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&
M2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6
M>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO
M*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A
M8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[
M)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>
M6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@
M(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*
M)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@
M)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^
M<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E
M<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`]
M('-O<G0@>PIL96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I"GT@9W)E<"!["B$O
M0E-$4$%.+PI](&=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N
M92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHO
M7E\\*"XK*20O(&%N9"`M92`D,2!A;F0@)&9I;&5S>R0Q?2LK(&9O<B!K97ES
M("4Z.CL*)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*;7D@)&QI8E]E
M>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF
M;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I
M.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE
M;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@
M)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O
M6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A
M=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F
M+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L
M("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U
M;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK
M.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?
M97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F
M:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D
M8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^
M>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@
M(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E
M;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?
M5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT
M+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B
M*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@
M;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X
M>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@
M)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N
M="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O
M1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R
M("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@
M)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN
M97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-
M1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ
M4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS
M."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE
M*"1O=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@
M;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^
M861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D
M8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE
M("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?
M;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H
M+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I
M*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM
M;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@
M)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ
M1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D
M;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,
M:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z
M:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[
M4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN
M="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X
M="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@
M)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]
M?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I
M/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]
M>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL
M93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M
M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC
M;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?
M;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B
M*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE
M(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA
M;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D
M7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z
M("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R
M8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL
M95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]
M("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N
M86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N
M86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E
M*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ
M4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T
M:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q
M=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R
M.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V
M87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X
M<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#
M;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*
M<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2
M.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T
M97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS
M,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E
M<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E
M(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E
M<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PI]"G-U8B!?<V5T7W!A
M<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N
M.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%2
M7U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q4
M14U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N
M9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W
M=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D
M("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U
M<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D
M("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R
M;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%
M32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D
M<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA
M;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!
M3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P
M96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R
M.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#
M2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T
M,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN
M97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-
M1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ
M4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS
M."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE
M*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X
M(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F
M:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T
M>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E
M('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7([
M"FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q
M(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D97AT+"`D8W)C*2`]($!?.PIM
M>2`H)&9H+"`D9FEL96YA;64I.PHD9FEL96YA;64@/2`B)'!A<E]T96UP+R1C
M<F,D97AT(CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PIU;FQI;FL@)&9I;&5N
M86UE(&EF("UE("1F:6QE;F%M93L*<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE
M.PI]"F5L<V4@>PIR971U<FX@*'5N9&5F+"`D9FEL96YA;64I(&EF("@M<B`D
M9FEL96YA;64I.PI]"F]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@
M)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0IS
M=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.
M04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O
M9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?
M5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X]
M(#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM0
M05)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I
M('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF
M:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U
M<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T
M:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[
M4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^
M(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S
M="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG
M>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N
M86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@
M)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I
M;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M
M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D
M96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.
M04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@
M)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L
M<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-0
M05=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%2
M1U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O
M(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]]
M(#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%2
M7T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#
M3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2![
M"F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.
M5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A
M<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!
M3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*
M<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R
M:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]
M"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R
M97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H
M;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD
M;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q
M=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M
M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N
M('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER
M96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*
M0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*
M0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH
M*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?
M7T5.1%]?"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````$``74!``%Q``````$`&Q%!`!KL00`:[``````0````$````!```"
M!0````$```(0`````0```AH````!```":0````$```/%````#!``$YP````-
M$`!K,````!D0`:[`````&P````0````:$`&NQ````!P````$;__^]1```8@`
M```%$``)@`````80``+@````"@``!4`````+````$````!4``````````Q`!
ML``````"```#,````!0````'````%Q``$&QP````$`&O]`````<0`!`D````
M"````W@````)````#&____X0``^4;____P````)O___P$``.P```````````
M```````````````````````````````````````````````````````````0
M`:[8```````````0`&G@$`!IY!``:>@0`&GL$`!I\!``:?00`&GX$`!I_!``
M:@`0`&H$$`!J"!``:@P0`&H0$`!J%!``:A@0`&H<$`!J(!``:B00`&HH$`!J
M+!``:C`0`&HT$`!J.!``:CP0`&I`$`!J1!``:D@0`&I,$`!J4!``:E00`&I8
M$`!J7!``:F`0`&ID$`!J:!``:FP0`&IP$`!J=!``:G@0`&I\$`!J@!``:H00
M`&J($`!JC!``:I`0`&J4$`!JF!``:IP0`&J@$`!JI!``:J@0`&JL$`!JL!``
M:K00`&JX$`!JO!``:L`0`&K$$`!JR!``:LP0`&K0$`!JU!``:M@0`&K<$`!J
MX!``:N00`&KH$`!J[```````````_____Q``;Y1'0T,Z("A$96)I86X@-"XY
M+C(M,3`I(#0N.2XR`$=#0SH@*$1E8FEA;B`T+C@N,RTQ,RD@-"XX+C,``"YS
M:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD
M+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG
M;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`
M+F9I;FD`+G)O9&%T80`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R
M87D`+FIC<@`N9V]T,@`N9'EN86UI8P`N9V]T`"YD871A`"YS9&%T80`N8G-S
M`"YC;VUM96YT````````````````````````````````````````````````
M````````````````"P````$````"$``!-````30````-```````````````!
M`````````!,````'`````A```40```%$````(```````````````!```````
M```A````!P````(0``%D```!9````"0```````````````0`````````-&__
M__8````"$``!B````8@```%8````!0`````````$````!````#X````+````
M`A```N````+@```&H`````8````!````!````!````!&`````P````(0``F`
M```)@```!4````````````````$`````````3F____\````"$``.P```#L``
M``#4````!0`````````"`````@```%MO___^`````A``#Y0```^4````D```
M``8````"````!`````````!J````!`````(0`!`D```0)````$@````%````
M``````0````,````=`````0```!"$``0;```$&P```,P````!0```!8````$
M````#````'X````!````!A``$YP``!.<````1```````````````!```````
M``"$`````0````80`!/@```3X```5U```````````````"``````````B@``
M``$````&$`!K,```:S`````L```````````````$`````````)`````!````
M`A``:V```&M@``!`.```````````````"`````````"8`````0````(0`*N8
M``"KF`````0```````````````0`````````H@````X````#$`&NP```KL``
M```$```````````````$`````````*X````/`````Q`!KL0``*[$````!```
M````````````!`````````"Z`````0````,0`:[(``"NR`````0`````````
M``````0`````````OP````$````#$`&NS```KLP````,```````````````!
M`````````,4````&`````Q`!KM@``*[8```!&`````8`````````!`````@`
M``#.`````0````,0`:_P``"O\````!````````````````0````$````>0``
M``$````#$`&P````L`````$0```````````````$`````````-,````!````
M`Q`!L1```+$0````#```````````````!`````````#9`````0````,0`;$<
M``"Q'`````0```````````````0`````````X`````@````#$`&Q(```L2``
M`!`X```````````````0`````````.4````!````,````````+$@````.@``
M`````````````0````$````!`````P````````````"Q6@```.X`````````
)``````$`````
